==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ruleoptionplugins/mark_target_option/kmfruleedittargetmark.h <==
/***************************************************************************
 begin                : Thu Aug 29 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com.orphi.iki
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITTARGETMARK_H
#define KMFRULEEDITTARGETMARK_H
#include "kmyfirewallruleeditortargetmark.h"

#include <qwidget.h>
#include <qptrlist.h>
/**
  *@author Christian Hubinger
  */

class IPTRule;
class QString;

class KMFRuleEditTargetMark : public KMyFirewallRuleEditorTargetMark {
	Q_OBJECT
public:
	KMFRuleEditTargetMark( QWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditTargetMark();
	void loadRule( IPTRule* );
	void accept();
	void reject();

public slots:
	void slotHelp();

private:
	IPTRule* m_rule;

signals:
	void sigAddTargetOpt( QString*, QPtrList<QString>* );
	void sigDelTargetOpt( QString * );
	void sigDocumentChanged();
	void sigHideMe();


};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ruleoptionplugins/mark_target_option/kmfruleedittargetmark.h <==
/***************************************************************************
 begin                : Thu Aug 29 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org.orphi.iki
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITTARGETMARK_H
#define KMFRULEEDITTARGETMARK_H
#include "kmyfirewallruleeditortargetmark.h"

#include <qwidget.h>
#include <qptrlist.h>
/**
  *@author Christian Hubinger
  */
class QString;
namespace KMF {
class IPTRule;


class KMFRuleEditTargetMark : public KMyFirewallRuleEditorTargetMark {
	Q_OBJECT
public:
	KMFRuleEditTargetMark( QWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditTargetMark();
	void loadRule( IPTRule* );
	void accept();
	void reject();

public slots:
	void slotHelp();

private:
	IPTRule* m_rule;

signals:
/*	void sigAddRuleOpt( QString*, QPtrList<QString>* );
	void sigAddTargetOpt( QString*, QPtrList<QString>* );
	void sigDelTargetOpt( QString * );*/
	void sigDocumentChanged();
	void sigHideMe();


};
}
#endif
